@@ -401,6 +401,8 @@ class COUNT(AggrFunctionDescr):
 class AVG(AggrFunctionDescr):
     rtype = 'Float'
 
+class ABS(FunctionDescr):
+    rtype = 'Float'
 class UPPER(FunctionDescr):
     rtype = 'String'
 class LOWER(FunctionDescr):
@@ -499,7 +501,7 @@ for func_class in (
     # aggregate functions
     MIN, MAX, SUM, COUNT, AVG,
     # transformation functions
-    UPPER, LOWER, LENGTH, DATE, RANDOM,
+    ABS, UPPER, LOWER, LENGTH, DATE, RANDOM,
     YEAR, MONTH, DAY, HOUR, MINUTE, SECOND, SUBSTRING,
     # keyword function
     IN):
@@ -654,6 +656,20 @@ class _GenericAdvFuncHelper(FTIndexerMixIn):
         else:
             return 'DROP INDEX %s' % idx
 
+    def sql_create_multicol_unique_index(self, table, columns):
+        columns = sorted(columns)
+        idx = 'unique_%s_%s_idx' % (table, '_'.join(columns))
+        sql = 'CREATE UNIQUE INDEX %s ON %s(%s);' % (idx.lower(),
+                                                     table,
+                                                     ','.join(columns))
+        return sql
+
+    def sql_drop_multicol_unique_index(self, table, columns):
+        columns = sorted(columns)
+        idx = 'unique_%s_%s_idx' % (table, '_'.join(columns))
+        sql = 'DROP INDEX %s;' % (idx.lower())
+        return sql
+
     def sql_create_sequence(self, seq_name):
         return '''CREATE TABLE %s (last INTEGER);
 INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
@@ -682,7 +698,7 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
         """
         return a temporary table name constructed from the table_name argument
         (e.g. for SQL Server, prepend a '#' to the name)
-        Standard implementation returns the argument unchanged. 
+        Standard implementation returns the argument unchanged.
         """
         return table_name
 
