@@ -140,6 +140,12 @@ AND j.column_id = k.column_id;"""
     def sql_set_null_allowed(self, table, column, coltype, null_allowed):
         raise NotImplementedError('use .set_null_allowed()')
 
+    def sql_drop_multicol_unique_index(self, table, columns):
+        columns = sorted(columns)
+        idx = 'unique_%s_%s_idx' % (table, '_'.join(columns))
+        sql = 'DROP INDEX %s ON %s;' % (idx.lower(), table)
+        return sql
+
     def change_col_type(self, cursor, table, column, coltype, null_allowed):
         alter = []
         drops = []
