@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-database.
+#
+# logilab-database is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation, either version 2.1 of the License, or (at your
+# option) any later version.
+#
+# logilab-database is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-database. If not, see <http://www.gnu.org/licenses/>.
 """
 unit tests for module logilab.common.db
 """
@@ -60,10 +77,10 @@ class PreferedDriverTC(TestCase):
 class GetCnxTC(TestCase):
     def setUp(self):
         try:
-            socket.gethostbyname('hercules')
+            socket.gethostbyname('centaurus')
         except:
             self.skip("those tests require specific DB configuration")
-        self.host = 'hercules'
+        self.host = 'centaurus'
         self.db = 'template1'
         self.user = getlogin()
         self.passwd = getlogin()
@@ -153,10 +170,6 @@ class DBAPIAdaptersTC(TestCase):
     def setUp(self):
         """Memorize original PREFERED_DRIVERS"""
         self.old_drivers = PREFERED_DRIVERS['postgres'][:]
-        self.host = 'crater.logilab.fr'
-        self.db = 'gincotest2'
-        self.user = 'adim'
-        self.passwd = 'adim'
 
     def tearDown(self):
         """Reset PREFERED_DRIVERS as it was"""
